@@ -2,6 +2,7 @@ package Elive::Entity::Group;
 use warnings; use strict;
 
 use Mouse;
+use Mouse::Util::TypeConstraints;
 
 use Elive::Entity;
 use base qw{ Elive::Entity };
@@ -15,9 +16,18 @@ __PACKAGE__->primary_key('groupId');
 has 'name' => (is => 'rw', isa => 'Str', required => 1,
 	       documentation => 'name of the group');
 
-has 'members' => (is => 'rw', isa => 'ArrayRef[Str]', required => 1,
+has 'members' => (is => 'rw', isa => 'ArrayRef[Str]|Elive::Array', required => 1,
+		  coerce => 1,
 		  documentation => "ids of users in the group");
 
+coerce 'ArrayRef[Str]' => from 'Str'
+          => via {
+	      my $a = [ split(';') ];
+	      bless ($a,'Elive::Array');
+	      $a;
+          };
+
+
 =head1 NAME
 
 Elive::Entity::Group - Elluminate Group entity instance class
@@ -33,17 +43,34 @@ for group selection of meeting participants.
 
 =cut
 
-=head2 construct
+=head2 insert
 
-    my $group = Elive::Entity::Group->construct({
+    #
+    # insert from an array of integers or strings
+    #
+    my $group = Elive::Entity::Group->insert({
 	name => 'Elluminati',
 	members => [111111, 222222, 333333 ],
      },
     );
 
-    $group->insert;
+    #
+    # insert from a ';' separated string of users
+    #
+    my $group = Elive::Entity::Group->insert({
+	name => 'Elluminati',
+	members => '111111;222222;333333',
+     },
+    );
 
-Construct a group from data.
+
+Inserts a new group from data.
+
+=cut
+
+=head2 update 
+
+    $group->update({members => '222222;333333;44444'});
 
 =cut
 
